@@ -6,12 +6,12 @@
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
 # 
+use 5.008;
 use strict;
 use warnings;
 
 package Dist::Zilla::Plugin::CriticTests;
-our $VERSION = '0.1.0';
-
+our $VERSION = '1.100140';
 # ABSTRACT: tests to check your code against best practices
 
 use Moose;
@@ -24,7 +24,6 @@ __PACKAGE__->meta->make_immutable;
 
 
 
-
 =pod
 
 =head1 NAME
@@ -33,7 +32,7 @@ Dist::Zilla::Plugin::CriticTests - tests to check your code against best practic
 
 =head1 VERSION
 
-version 0.1.0
+version 1.100140
 
 =head1 SYNOPSIS
 
@@ -50,12 +49,10 @@ the following files:
 
 =item * t/author/critic.t - a standard test to check your code against best practices
 
-=back 
+=back
 
 This plugin does not accept any option yet.
 
-
-
 =head1 AUTHOR
 
   Jerome Quelin
@@ -67,17 +64,19 @@ This software is copyright (c) 2009 by Jerome Quelin.
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
-=cut 
-
+=cut
 
 
 __DATA__
 ___[ xt/author/critic.t ]___
 #!perl
 
+use strict;
+use warnings;
+
 use Test::More;
 use English qw(-no_match_vars);
 
 eval "use Test::Perl::Critic";
 plan skip_all => 'Test::Perl::Critic required to criticise code' if $@;
-all_critic_ok();
\ No newline at end of file
+all_critic_ok();
